@@ -2,7 +2,7 @@
 
 #
 # DaVinci Resolve 16.1.1 Debian package creator
-# Release 2019-11-03
+# Release 2019-11-09
 # By Daniel Tufvesson
 #
 
@@ -58,7 +58,7 @@ make_executable() {
 
 # Setup variables
 RESOLVE_VERSION=16.1.1
-DEB_STEPPING=2
+DEB_STEPPING=3
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -135,6 +135,9 @@ cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
 EOF
 
+# Fix missing x flag
+chmod +x ${RESOLVE_BASE_DIR}/bin/DaVinciPanelDaemon
+
 # Install panel API library
 create_directory ${DEB_DIR}/usr/lib/x86_64-linux-gnu
 extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/x86_64-linux-gnu libDaVinciPanelAPI.so
